@@ -29,7 +29,7 @@ import logging
 log = logging.getLogger('nbxmpp.client_nb')
 
 
-class NonBlockingClient:
+class NonBlockingClient(object):
     """
     Client class is XMPP connection mountpoint. Objects for authentication,
     network communication, roster, xml parsing ... are plugged to client object.
@@ -72,6 +72,7 @@ class NonBlockingClient:
         self.stream_started = False
         self.disconnecting = False
         self.protocol_type = 'XMPP'
+        self.alpn = False
 
     def disconnect(self, message=''):
         """
@@ -150,7 +151,7 @@ class NonBlockingClient:
 
     def connect(self, on_connect, on_connect_failure, hostname=None, port=5222,
     on_proxy_failure=None, on_stream_error_cb=None, proxy=None,
-    secure_tuple=('tls', None, None, None, None)):
+    secure_tuple=('tls', None, None, None, None, False)):
         """
         Open XMPP connection (open XML streams in both directions)
 
@@ -160,23 +161,27 @@ class NonBlockingClient:
         :param port: port number of XMPP server
         :param on_proxy_failure: called if error occurs during TCP connection
             to proxy server or during proxy connecting process
+        :param on_stream_error_cb: called if error occurs
         :param proxy: dictionary with proxy data. It should contain at least
             values for keys 'host' and 'port' - connection details for proxy
             serve and optionally keys 'user' and 'pass' as proxy credentials
         :param secure_tuple: tuple of (desired connection type, cacerts,
-            mycerts, tls_version, cipher_list)
+            mycerts, tls_version, cipher_list, alpn)
             connection type can be 'ssl' - TLS established after TCP connection,
                 'tls' - TLS established after negotiation with starttls, or
                 'plain'.
-            cacerts, mycerts, tls_version, cipher_list - see tls_nb.NonBlockingTLS
-                constructor for more details
+            cacerts, mycerts, tls_version, cipher_list, alpn
+                see tls_nb.NonBlockingTLS constructor for more details
         """
         self.on_connect = on_connect
         self.on_connect_failure=on_connect_failure
         self.on_proxy_failure = on_proxy_failure
         self.on_stream_error_cb = on_stream_error_cb
         self.desired_security, self.cacerts, self.mycerts, self.tls_version, \
-            self.cipher_list = secure_tuple
+            self.cipher_list = secure_tuple[:5]
+        if len(secure_tuple) == 6:
+            # ALPN support was added in version 0.6.3
+            self.alpn = secure_tuple[5]
         self.Connection = None
         self.Port = port
         self.proxy = proxy
@@ -238,6 +243,7 @@ class NonBlockingClient:
                     certs=certs,
                     tls_version = self.tls_version,
                     cipher_list = self.cipher_list,
+                    alpn=self.alpn,
                     proxy_dict=proxy_dict)
 
         # plug transport into client as self.Connection
@@ -273,9 +279,9 @@ class NonBlockingClient:
         """
         if err_message:
             log.debug('While looping over DNS A records: %s' % err_message)
-        if self.ip_addresses == []:
+        if not self.ip_addresses:
             msg = 'Run out of hosts for name %s:%s.' % (self.Server, self.Port)
-            msg = msg + ' Error for last IP: %s' % err_message
+            msg += ' Error for last IP: %s' % err_message
             self.disconnect(msg)
         else:
             self.current_ip = self.ip_addresses.pop(0)
@@ -498,10 +504,10 @@ class NonBlockingClient:
                 if self.protocol_type != 'BOSH':
                     self._channel_binding = self.Connection.NonBlockingTLS.get_channel_binding()
                     # TLS handshake is finished so channel binding data muss exist
-                    assert (self._channel_binding != None)
+                    assert (self._channel_binding is not None)
             except NotImplementedError:
                 pass
-        if auth_mechs == None:
+        if auth_mechs is None:
             self._auth_mechs = SASL_AUTHENTICATION_MECHANISMS | set(['XEP-0078'])
         else:
             self._auth_mechs = auth_mechs
@@ -556,7 +562,7 @@ class NonBlockingClient:
         """
         if data:
             self.Dispatcher.ProcessNonBlocking(data)
-        if not 'SASL' in self.__dict__:
+        if 'SASL' not in self.__dict__:
             # SASL is pluged out, possible disconnect
             return
         if self.SASL.startsasl == 'in-process':
